'use strict';

var tv4 = require('tv4');

module.exports.validate = function(objects, schema, flatten) {

  if(!objects || !schema) throw new Error("parameters missing");

  if (!Array.isArray(objects)) throw new Error('objects parameter must contain an array.');

  if (typeof flatten == 'undefined') {
    flatten = true;
  }

  var errors = tv4.validateMultiple(objects, schema).errors;

  if (errors.length <= 0) {
    if (flatten) return flattenValuesInternally(objects);
    return true;
  }

  errors.forEach(function (error) {
    var data = error.dataPath.split('/');
    var index = data[1];
    var property = data[2];
    objects[index][property].valid = false;
  });

  if (flatten) return [];
  return false;
}

var flattenValueInternal = function(object) {
  var props = {};
  for (var prop in object) {
    if (typeof object[prop] === 'object')
      props[prop] = object[prop].value;
  }

  return props;
}

module.exports.flattenValue = function(object) {
  return flattenValueInternal(object)
}

var flattenValuesInternally = function(objects) {
  var flattened = [];
  var self = this;
  objects.forEach(obj => {
    var r = flattenValueInternal(obj);
    flattened.push(r);
  });

  return flattened;
}

module.exports.flattenValues = function(objects) {
  return flattenValuesInternally(objects);
}



module.exports.setPristine = function(objects) {
  objects.forEach(function(obj) {
    for (var prop in obj) {
      if (typeof obj[prop] === 'object')
        obj[prop].valid = true;
    }
  })
}

module.exports.toValidationModel = function(objects) {
  var validatedObjects = [];
  objects.forEach(function(obj) {
    var transformedObject = {}
    for (var prop in obj) {
      var transformedProperty = {
        value: obj[prop],
        placeholder: '',
        error: '',
        valid: true
      }

      transformedObject[prop] = transformedProperty;
    }

    validatedObjects.push(transformedObject);
  });

  return validatedObjects;
}